@@ -25,7 +25,7 @@
 #include "nxml.h"
 
 char *
-nxml_strerror (nxml_error_t err)
+nxml_strerror (nxml_t * nxml, nxml_error_t err)
 {
   switch (err)
     {
@@ -35,6 +35,12 @@ nxml_strerror (nxml_error_t err)
     case NXML_ERR_PARSER:
       return "Parser error";
 
+    case NXML_ERR_DOWNLOAD:
+      return nxml
+	&& nxml->priv.curl_error ? (char *) curl_easy_strerror (nxml->priv.
+								curl_error) :
+	"Download error";
+
     case NXML_ERR_DATA:
       return "No correct paramenter in the function";
 
@@ -43,6 +49,15 @@ nxml_strerror (nxml_error_t err)
     }
 }
 
+CURLcode
+nxml_curl_error (nxml_t * nxml, nxml_error_t err)
+{
+  if (!nxml || err != NXML_ERR_DOWNLOAD)
+    return CURLE_OK;
+
+  return nxml->priv.curl_error;
+}
+
 nxml_error_t
 nxml_line_error (nxml_t * nxml, int *line)
 {
