@@ -25,7 +25,7 @@ main (int argc, char **argv)
   if (ret)
     {
       fprintf (stderr, "NXML return error (parsing): %s\n",
-	       nxml_strerror (ret));
+	       nxml_strerror (data, ret));
       nxml_free (data);
       return 1;
     }
@@ -35,7 +35,7 @@ main (int argc, char **argv)
   if (ret)
     {
       fprintf (stderr, "NXML return error (writing): %s\n",
-	       nxml_strerror (ret));
+	       nxml_strerror (data, ret));
       nxml_free (data);
       return 1;
     }
